@@ -179,7 +179,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                                     popup.dispose();
                                     this.fireEvent('popupClosed');
                                 },this,100);
-                                if (!btnCfg.option && !btnCfg.option.noReload){
+                                if (!(btnCfg.options && btnCfg.options.noReload)){
                                     this.fireDataEvent('actionResponse',{action: 'reload'});
                                 }
                             },this);
